@@ -148,17 +148,40 @@ extractConsequenceEnrichment(
     exampleSwitchListAnalyzed,
     consequencesToAnalyze='all',
     analysisOppositeConsequence = TRUE,
+    localTheme = theme_bw(base_size = 14), # Increase font size in vignette
     returnResult = FALSE # if TRUE returns a data.frame with the summary statistics
 )
 
 ## ---- fig.width=12, fig.height=4----------------------------------------------
 extractConsequenceEnrichmentComparison(
     exampleSwitchListAnalyzed,
-    consequencesToAnalyze=c('domains_identified','intron_retention','coding_potential'),
+    consequencesToAnalyze=c('domains_identified','coding_potential'),
     analysisOppositeConsequence = TRUE,
     returnResult = FALSE # if TRUE returns a data.frame with the summary statistics
 )
 
+## ---- fig.width=9, fig.height=5-----------------------------------------------
+extractSubCellShifts(
+    exampleSwitchListAnalyzed,
+    returnResult = FALSE # returns plot instead of data
+)
+
+## ---- fig.width=9, fig.height=5-----------------------------------------------
+### Extract shifts
+locChange <- extractSubCellShifts(
+    exampleSwitchListAnalyzed,
+    returnResult = TRUE # returns data insted of plot
+)
+
+### Sort
+locChange <- locChange[sort.list(
+    locChange$n_genes,
+    decreasing = TRUE
+),]
+
+### View
+head(locChange, 3)
+
 ## ---- fig.width=12, fig.height=4.5--------------------------------------------
 extractSplicingEnrichment(
     exampleSwitchListAnalyzed,
@@ -352,10 +375,9 @@ data("exampleSwitchList")
 exampleSwitchList <- preFilter(exampleSwitchList, geneExpressionCutoff = 4) # preFilter for fast runtime
 
 # Perform test (takes ~10 sec)
-exampleSwitchListAnalyzed <- isoformSwitchTestDRIMSeq(
+exampleSwitchListAnalyzed <- isoformSwitchTestSatuRn(
     switchAnalyzeRlist = exampleSwitchList,
-    testIntegration='isoform_only',
-    reduceToSwitchingGenes=TRUE
+    reduceToSwitchingGenes = TRUE
 )
 
 # Summarize switching features
@@ -374,6 +396,12 @@ exampleSwitchListAnalyzed <- extractSequence(
 )
 
 ## -----------------------------------------------------------------------------
+### Please note the way of importing files in the following example with
+# "system.file('pathToFile', package="IsoformSwitchAnalyzeR") is
+# just a way to accessing the example data in the IsoformSwitchAnalyzeR package
+# and not something you need to do - just supply the string e.g.
+# "myAnnotation/predicted_annoation.txt" to the function.
+
 ### Load test data (matching the external sequence analysis results)
 data("exampleSwitchListIntermediary")
 exampleSwitchListIntermediary
@@ -406,13 +434,28 @@ exampleSwitchListAnalyzed <- analyzeSignalP(
     pathToSignalPresultFile  = system.file("extdata/signalP_results.txt", package = "IsoformSwitchAnalyzeR")
 )
 
-### Add NetSurfP2 analysis
+### Add IUPred2A analysis
 exampleSwitchListAnalyzed <- analyzeIUPred2A(
     switchAnalyzeRlist        = exampleSwitchListAnalyzed,
     pathToIUPred2AresultFile = system.file("extdata/iupred2a_result.txt.gz", package = "IsoformSwitchAnalyzeR"),
     showProgress = FALSE
 )
 
+### Add DeepLoc2 analysis
+exampleSwitchListAnalyzed <- analyzeDeepLoc2(
+    switchAnalyzeRlist = exampleSwitchListAnalyzed,
+    pathToDeepLoc2resultFile = system.file("extdata/deeploc2.csv", package = "IsoformSwitchAnalyzeR"),
+    quiet = FALSE
+)
+
+### Add DeepTMHMM analysis
+exampleSwitchListAnalyzed <- analyzeDeepTMHMM(
+    switchAnalyzeRlist   = exampleSwitchListAnalyzed,
+    pathToDeepTMHMMresultFile = system.file("extdata/DeepTMHMM.gff3", package = "IsoformSwitchAnalyzeR"),
+    showProgress=FALSE
+)
+
+
 exampleSwitchListAnalyzed
 
 ## -----------------------------------------------------------------------------
